# Copyright 2012 Leonidas Poulopoulos
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import datetime
import time

def asdayPeriod(timestamp):
    '''
    Transforms a python datetime timestamp to Alcatel friendly timestamp
    
    @type timestamp: Python datetime
    @param timestamp: The datetime timestamp
    
    @rtype: String
    @return: An Alcatel-friendly string: YYYYMMDDQH where QH in [00,96] representing 15min periods in a day.
    '''
    daystring = timestamp.strftime('%Y%m%d')
    dayquarter = "%s" %((timestamp.hour*60 + timestamp.minute)//15)
    return "%s%s" %(daystring,dayquarter.zfill(2))

def fromdayPeriod(timestring):
    '''
    Transforms an Alcatel-friendly timestamp to a python datetime timestamp
    
    @type timestring: String
    @param timestring: An Alcatel-friendly string: YYYYMMDDQH where QH in [00,96] representing 15min periods in a day.
    
    @rtype: Datetime
    @return: A python datetime timestamp
    '''
    textdate = timestring[0:8]
    dayquarter = timestring[8:10]
    # we "steal" a quarter of an hour here...
    daymins = (int(dayquarter)-1)*15
    hours = daymins//60
    mins = daymins - hours*60
    datetimestamp = datetime.datetime(*time.strptime(textdate, '%Y%m%d')[:3]+(hours, mins))
    # ...and we return it here:
    datetimestamp = datetimestamp + datetime.timedelta(minutes=15)
    return datetimestamp

